#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HUnit
version: 1.3.1.1
id: HUnit-1.3.1.1-21d4c913eac2236e948873e3db41c801
key: HUnit_7IPmJa5HmrxHl6ny5upchm
license: BSD3
maintainer: Simon Hengel <sol@typeful.net>
stability: stable
homepage: https://github.com/hspec/HUnit#readme
synopsis: A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.
category: Testing
author: Dean Herington
exposed: True
exposed-modules:
    Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal Test.HUnit.Text
    Test.HUnit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/HUnit-1.3.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/HUnit-1.3.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/HUnit-1.3.1.1
hs-libraries: HSHUnit-1.3.1.1-7IPmJa5HmrxHl6ny5upchm
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
haddock-interfaces: /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html: /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
